#include <string>

#import <Foundation/Foundation.h>
#import "PokktManager.h"
#import "PokktController.h"
#import "VideoResponse.h"
#import "PokktConfig.h"

// game object name
#define UnityListenerGOName             "pokktDispatcher"

// events
#define VideoDisplayedEvent             "VideoDisplayed"
#define VideoSkippedEvent               "VideoSkipped"
#define VideoClosedEvent                "VideoClosed"
#define VideoCompletedEvent             "VideoCompleted"
#define VideoGratifiedEvent             "VideoGratified"
#define DownloadCompletedEvent          "DownloadCompleted"
#define DownloadFailedEvent             "DownloadFailed"

PokktConfig *pokktConfig = [[PokktConfig alloc]init];

@interface PokktNativeExtension:NSObject<PokktDelegate>
@end

extern "C"
{
    void playVideo(bool incentivised, NSString *screenName)
    {
        // set the view controller
        UIViewController *viewController = [[[UIApplication sharedApplication] keyWindow] rootViewController];
        [PokktManager setPresentView:viewController];
        pokktConfig.screenName = screenName;
        pokktConfig.incentivised = incentivised;
        [PokktManager playVideoCampaign:pokktConfig];
    }
    
    void NotifyIOS(const char* operation, const char* param)
    {
        NSString *operationNSStr = [NSString stringWithUTF8String:(operation)];
        NSString *paramNSStr = [NSString stringWithUTF8String:(param)];
        
        
        // Utility Methods
        [operationNSStr isEqualToString:@""];
        if ([operationNSStr isEqualToString:@"setDebug"])
        {
            BOOL debug = [paramNSStr isEqualToString:@"true"];
            [PokktManager setDebug:debug];
        }
        
        else if ([operationNSStr isEqualToString:@"showLog"])
            NSLog(@"ShowLog is not supported by the iOS Plugin.");
        
        else if ([operationNSStr isEqualToString:@"showToast"])
            NSLog(@"ShowToast is not supported by the iOS Plugin.");
        
        else if ([operationNSStr isEqualToString:@"exportLog"])
        {
            // set the view controller
            UIViewController *viewController = [[[UIApplication sharedApplication] keyWindow] rootViewController];
            [PokktManager setPresentView:viewController];
            [PokktManager exportPokktSDKLog];
        }
        
        else if ([operationNSStr isEqualToString:@"setThirdPartyUserId"])
            pokktConfig.thirdPartyUserId = paramNSStr;
        
        
        // Essential Methods
        
        else if ([operationNSStr isEqualToString:@"setSecurityKey"])
            [pokktConfig setSecurityKey:[NSString stringWithUTF8String:param]];
        
        else if ([operationNSStr isEqualToString:@"setApplicationId"])
            [pokktConfig setApplicationId:[NSString stringWithUTF8String:param]];
        
        else if ([operationNSStr isEqualToString:@"setAutoCaching"])
            pokktConfig.autoCacheVideo = [paramNSStr boolValue];
        
        else if ([operationNSStr isEqualToString:@"setIntegrationType"])
            NSLog(@"setIntegrationType is not needed for IOS.");
        
        else if ([operationNSStr isEqualToString:@"initPokkt"])
        {
            // set the view controller
            UIViewController *viewController = [[[UIApplication sharedApplication] keyWindow] rootViewController];
            [PokktManager setPresentView:viewController];
            
            [PokktManager initPokkt:pokktConfig];
            
            PokktNativeExtension *ext = [[PokktNativeExtension alloc] init];
            [PokktManager setPokktDelegate:ext];
        }
        
        else if ([operationNSStr isEqualToString:@"sendAppInfo"])
            [PokktManager appInstallFirstTime];
        
        
        // Session Methods
        
        else if ([operationNSStr isEqualToString:@"startSession"])
            [PokktManager startSession:pokktConfig];
        
        else if ([operationNSStr isEqualToString:@"endSession"])
            [PokktManager endSession];
        
        
        // OfferWall Methods -- NOT Supported in iOS Plugin  -- should go to default log case.
        
        
        // Video Methods
        
        else if ([operationNSStr isEqualToString:@"getVideo"])
            playVideo(YES, paramNSStr);
        
        else if ([operationNSStr isEqualToString:@"getVideoNonIncent"])
            playVideo(NO, paramNSStr);
        
        else if ([operationNSStr isEqualToString:@"cacheVideoCampaign"])
            [PokktManager cacheVideoCampaign:pokktConfig];
        
        else if ([operationNSStr isEqualToString:@"setSkipEnabled"])
            pokktConfig.skipEnabled = [paramNSStr isEqualToString:@"true"];
        
        else if ([operationNSStr isEqualToString:@"setDefaultSkipTime"])
            pokktConfig.defaultSkipTime = [paramNSStr intValue];
        
        else if ([operationNSStr isEqualToString:@"setCustomSkipMessage"])
            pokktConfig.customSkipMessage = paramNSStr;
        
        else if ([operationNSStr isEqualToString:@"setBackButtonDisabled"])
            NSLog(@"setBackButtonDisabled is not supported by the iOS Plugin.");
        
        else if ([operationNSStr isEqualToString:@"setRetryDuration"])
            pokktConfig.retryDuration = [paramNSStr intValue];
        
        
        // Common Methods
        
        else if ([operationNSStr isEqualToString:@"setName"])
            pokktConfig.name = paramNSStr;
        
        else if ([operationNSStr isEqualToString:@"setAge"])
            pokktConfig.age = paramNSStr;
        
        else if ([operationNSStr isEqualToString:@"setSex"])
            pokktConfig.sex = paramNSStr;
        
        else if ([operationNSStr isEqualToString:@"setMobileNo"])
            pokktConfig.mobileNo = paramNSStr;
        
        else if ([operationNSStr isEqualToString:@"setEmailAddress"])
            pokktConfig.emailAddress = paramNSStr;
        
        else if ([operationNSStr isEqualToString:@"setLocation"])
            pokktConfig.location = paramNSStr;
        
        else if ([operationNSStr isEqualToString:@"setBirthday"])
            pokktConfig.birthday = paramNSStr;
        
        else if ([operationNSStr isEqualToString:@"setMaritalStatus"])
            pokktConfig.maritalStatus = paramNSStr;
        
        else if ([operationNSStr isEqualToString:@"setFacebookId"])
            pokktConfig.facebookId = paramNSStr;
        
        else if ([operationNSStr isEqualToString:@"setTwitterHandle"])
            pokktConfig.twitterHandle = paramNSStr;
        
        else if ([operationNSStr isEqualToString:@"setEducation"])
            pokktConfig.education = paramNSStr;
        
        else if ([operationNSStr isEqualToString:@"setNationality"])
            pokktConfig.nationality = paramNSStr;
        
        else if ([operationNSStr isEqualToString:@"setEmployment"])
            pokktConfig.employment = paramNSStr;
        
        else if ([operationNSStr isEqualToString:@"setMaturityRating"])
            pokktConfig.maturityRating = paramNSStr;
        
        
        // Analytics Methods
        
        else if ([operationNSStr isEqualToString:@"googleAnalyticsID"])
            pokktConfig.googleTrackerID = paramNSStr;
        
        else if ([operationNSStr isEqualToString:@"mixPanelProjectToken"])
            pokktConfig.mixPanelTrackerID = paramNSStr;
        
        else if ([operationNSStr isEqualToString:@"flurryApplicationKey"])
            pokktConfig.flurryTrackerID = paramNSStr;
        
        else if ([operationNSStr isEqualToString:@"selectedAnalyticsType"])
        {
            if ([paramNSStr isEqualToString:@"FLURRY"])
                pokktConfig.eventType = FLURRY_ANALYTICS;
            
            else if ([paramNSStr isEqualToString:@"GOOGLE_ANALYTICS"])
                pokktConfig.eventType = GOOGLE_ANALYTICS;
            
            else if ([paramNSStr isEqualToString:@"MIXPANNEL"])
                pokktConfig.eventType = MIXPANNEL_ANALYTICS;
        }
        
        else
            NSLog(@"Operation %s is not supported by the iOS Plugin.", operation);
    }
    
    bool IsVideoAvailableOnIOS()
    {
        return [PokktManager isVideoAvailable];
    }
    
    float GetVideoVCOnIOS()
    {
        return [PokktManager getVideoVc];
    }
    
    const char* GetPokktSDKVersionOnIOS()
    {
        const char* version = [[NSString stringWithFormat:@"%@", [PokktManager getSDKVersion]] UTF8String];
        return version;
    }
}

// use this to notify the unity observer
static void NotifyUnity(const char* operation, const char*  param)
{
    UnitySendMessage(UnityListenerGOName, operation, param);
}

@implementation PokktNativeExtension

#pragma mark - Pokkt Delegates

- (void)didFinishedVideoDownload:(BOOL)isFinished
{
    float vc = [PokktManager getVideoVc];
    NotifyUnity(DownloadCompletedEvent, [[NSString stringWithFormat:@"%@", [[NSNumber numberWithFloat:vc] stringValue]] UTF8String]);
}

- (void)didFailedVideoDownload:(NSString *)error
{
    NotifyUnity(DownloadFailedEvent, [[NSString stringWithFormat:@"%@", error] UTF8String]);
}

- (void)onVideoCompleated:(BOOL)isCompleated
{
    NotifyUnity(VideoCompletedEvent, "Video is completed");
}

- (void)onVideoDisplayed
{
    NotifyUnity(VideoDisplayedEvent, "Video is displayed");
}

- (void)onVideoClosed
{
    NotifyUnity(VideoClosedEvent, "Video is closed");
}

- (void)onVideoGratified:(VideoResponse *)videoResponse
{
    NotifyUnity(VideoGratifiedEvent, [[NSString stringWithFormat:@"%@", videoResponse.coins] UTF8String]);
}

- (void)onVideoSkipped
{
    NotifyUnity(VideoSkippedEvent, "Video is skipped");
}

@end