using UnityEngine;
using UnityEngine.UI;
using Pokkt;

public class VideoOperations : MonoBehaviour
{
	// exposed properties
	public GameObject ScreenManagerGO;
	public Button StartCacheButton;
	public Button PlayVideoIncentButton;
	public Button PlayVideoNonIncentButton;
	public Text PointsEarned;
	public Text StatusMessage;

	// internal states
	private float _totalPointsEarned;
    private PokktConfig _pokktConfig;

	void Awake()
	{
		// you will need PokktConfig at different method calls
		// it is single place for all SDK related info
	    _pokktConfig = new PokktConfig
	    {
			// SampleApp default Credentials (use the credentials provided to you)
			//SecurityKey = "iJ02lJss0M",
			//ApplicationId = "a2717a45b835b5e9f50284a38d62a74e",
			
			// Swaraj's Credentials
            //SecurityKey = "1bf593c3c10a07ca0545f63f6bfaa778",
	        //ApplicationId = "9e0141d9faeab8f3d3fb45ff506b0eb8",

			// SurajTestAppiOS  Credentials
			//SecurityKey = "ae501f1003b0dc927dea807498ceaf3c",
			//ApplicationId = "954b975f9c753bcb8fca42624d78139a",
			
			// PokktSampleApp Credentials
			SecurityKey = "91f118562047d230f2b907ba93d2c4e2",
			ApplicationId = "4317fb1fcbf1ca98badf08ef59b0b86b",

            IntegrationType = PokktIntegrationType.INTEGRATION_TYPE_ALL,

            // set default auto-caching behaviour
	        AutoCacheVideo = Storage.getAutoCaching(),

            // this will be a unique id per user from developer side
            // developer is free to choose any String data point.
            ThirdPartyUserId = "123456",

    		// set default skip behaviour
	    	DefaultSkipTime = 10,
		    SkipEnabled = true,

		    ScreenName = "sample_screen",
	    };

	    // enable 'Start Caching' button in case of manual caching
		StartCacheButton.gameObject.SetActive(!Storage.getAutoCaching());

		// handle pokkt video ad events
		PokktManager.Dispatcher.VideoClosedEvent += (string message) =>
		{
			StatusMessage.text = message;
		};

		PokktManager.Dispatcher.VideoSkippedEvent += (string message) =>
		{
			StatusMessage.text = message;
		};

		PokktManager.Dispatcher.VideoCompletedEvent += (string message) =>
		{
			StatusMessage.text = message;
		};
		
		PokktManager.Dispatcher.VideoGratifiedEvent += (string message) =>
		{
			_totalPointsEarned += float.Parse(message);
			
			PointsEarned.text = "Points Earned: " + _totalPointsEarned.ToString();
			StatusMessage.text = "Points earned from last video: " + message;
		};
		
		PokktManager.Dispatcher.VideoDisplayedEvent += (string message) =>
		{
			StatusMessage.text = message;
		};
		
		PokktManager.Dispatcher.DownloadCompletedEvent += OnDownloadCompleted;
		
		PokktManager.Dispatcher.DownloadFailedEvent += (string message) =>
		{
			StatusMessage.text = message;
		};

		// it is mandatory to call init.
		PokktManager.InitPokkt();

		// if video is available then enable the buttons
		if (PokktManager.IsVideoAvailable())
		{
			float vc = PokktManager.GetVideoVc();
			OnDownloadCompleted(vc.ToString());
		}
	}

	private void OnDownloadCompleted(string message)
	{
		StatusMessage.text = "Download Completed! VC is: " + message;
		
		// enable playback buttons
		PlayVideoIncentButton.gameObject.SetActive(true);
		PlayVideoNonIncentButton.gameObject.SetActive(true);
		
		// get the video vc
		PlayVideoIncentButton.GetComponentInChildren<Text>().text = "Play Video To Earn: " + message;
	}

	void Start()
	{
	}
	
	void Update()
	{
		if (Input.GetKeyDown(KeyCode.Escape))
		{
			ScreenManagerGO.GetComponent<ScreenManager>().OpenScreen("CampaignSelectorScreen");

			// disable buttons
			StartCacheButton.gameObject.SetActive(!Storage.getAutoCaching());
			PlayVideoIncentButton.gameObject.SetActive(false);
			PlayVideoNonIncentButton.gameObject.SetActive(false);
		}
	}

	public void StartCaching()
	{
		PokktManager.CacheVideoCampaign();
	}

	public void PlayVideo(bool incent)
	{
		if (incent)
			PokktManager.GetVideo(_pokktConfig);
		else
			PokktManager.GetVideoNonIncent(_pokktConfig);
	}

	public void ExportLog()
	{
		PokktManager.ExportLog();
	}
}
