﻿using UnityEngine;

namespace Pokkt
{
	internal static class PokktNativeExtension
	{

		public static IPerformer GetPerformer()
		{
		    if (Application.platform == RuntimePlatform.Android)
		        return new AndroidPerformer();

		    if (Application.platform == RuntimePlatform.IPhonePlayer)
		        return new IOSPerformer();

#if UNITY_WSA
            if (Application.platform == RuntimePlatform.WSAPlayerARM || 
                Application.platform == RuntimePlatform.WSAPlayerX64 || 
                Application.platform == RuntimePlatform.WSAPlayerX86)
                return new WindowsPhonePerformer();
#endif

            Debug.LogWarning("[UNITY] Performer not implemented for platform: " + Application.platform);
		    return null;
		}

	    public static void PerformOperation(PokktOperations operation, string param = "")
		{
			switch (operation)
			{
			// utility methods
			case PokktOperations.SetDebug:					NotifyNative("setDebug",				param); break;
			case PokktOperations.ShowLog:					NotifyNative("showLog",					param); break;
			case PokktOperations.ShowToast:					NotifyNative("showToast",				param); break;
			case PokktOperations.ExportLog:					NotifyNative("exportLog",				param); break;
			case PokktOperations.SetThirdPartyUserId:		NotifyNative("setThirdPartyUserId",		param); break;
			
			// essential methods
			case PokktOperations.SetSecurityKey:			NotifyNative("setSecurityKey",			param); break;
			case PokktOperations.SetApplicationId:			NotifyNative("setApplicationId",		param); break;
			case PokktOperations.SetIntegrationType:		NotifyNative("setIntegrationType",		param); break;
			case PokktOperations.SetAutoCaching:			NotifyNative("setAutoCaching",			param); break;
			case PokktOperations.InitPokkt:					NotifyNative("initPokkt",				param); break;
			case PokktOperations.SendAppInfo:				NotifyNative("sendAppInfo",				param); break;
			
			// session methods
			case PokktOperations.StartSession:       		NotifyNative("startSession",     		param); break;
			case PokktOperations.EndSession:       			NotifyNative("endSession",     			param); break;
			
			// offerwall methods
			case PokktOperations.SetCloseOnSuccessFlag:     NotifyNative("setCloseOnSuccessFlag",   param); break;
			case PokktOperations.GetCoins:              	NotifyNative("getCoins",            	param); break;
			case PokktOperations.GetPendingCoins:           NotifyNative("getPendingCoins",     	param); break;
			case PokktOperations.CheckOfferWallCampaign:    NotifyNative("checkOfferWallCampaign",  param); break;
			
			// video methods
			case PokktOperations.GetVideo:                  NotifyNative("getVideo",            	param); break;
			case PokktOperations.GetVideoNonIncent:    		NotifyNative("getVideoNonIncent",   	param); break;					
			case PokktOperations.CacheVideoCampaign:        NotifyNative("cacheVideoCampaign",      param); break;
			case PokktOperations.SetSkipEnabled:          	NotifyNative("setSkipEnabled",        	param); break;
			case PokktOperations.SetDefaultSkipTime:    	NotifyNative("setDefaultSkipTime",      param); break;
			case PokktOperations.SetCustomSkipMessage:    	NotifyNative("setCustomSkipMessage",    param); break;
			case PokktOperations.SetBackButtonDisabled:    	NotifyNative("setBackButtonDisabled",   param); break;
			case PokktOperations.SetRetryDuration:    		NotifyNative("setRetryDuration",   		param); break;

			// optional methods
			case PokktOperations.SetName:                   NotifyNative("setName",                 param); break;
			case PokktOperations.SetAge:                    NotifyNative("setAge",              	param); break;
			case PokktOperations.SetSex:                    NotifyNative("setSex",              	param); break;
			case PokktOperations.SetMobileNo:               NotifyNative("setMobileNo",             param); break;
			case PokktOperations.SetEmailAddress:           NotifyNative("setEmailAddress",         param); break;
			case PokktOperations.SetLocation:               NotifyNative("setLocation",             param); break;
			case PokktOperations.SetBirthday:               NotifyNative("setBirthday",             param); break;
			case PokktOperations.SetMaritalStatus:          NotifyNative("setMaritalStatus",        param); break;
			case PokktOperations.SetFacebookId:             NotifyNative("setFacebookId",           param); break;
			case PokktOperations.SetTwitterHandle:          NotifyNative("setTwitterHandle",        param); break;
			case PokktOperations.SetEducation:          	NotifyNative("setEducation",    		param); break;
			case PokktOperations.SetNationality:            NotifyNative("setNationality",          param); break;
			case PokktOperations.SetEmployment:       		NotifyNative("setEmployment",     		param); break;
			case PokktOperations.SetMaturityRating:         NotifyNative("setMaturityRating",       param); break;
			
			// analytics methods
			case PokktOperations.SetGoogleAnalyticsId:		NotifyNative("setGoogleAnalyticsID",	param); break;
			case PokktOperations.SetMixPanelProjectToken:	NotifyNative("setMixPanelProjectToken",	param); break;
			case PokktOperations.SetFlurryApplicationKey:	NotifyNative("setFlurryApplicationKey",	param); break;
			case PokktOperations.SetSelectedAnalyticsType:	NotifyNative("setSelectedAnalyticsType",param); break;
			}
		}

		private static void NotifyNative(string operation, string param)
		{
			Debug.Log("[UNITY] Performing operation: " + operation + " with params: " + param);
			IPerformer performer = GetPerformer();
			if (performer != null)
				performer.NotifyNative(operation, param);
		}

		public static bool IsVideoAvailable()
		{
			Debug.Log("[UNITY] Checking video availability...");
			IPerformer performer = GetPerformer();
			if (performer != null)
				return performer.IsVideoAvailable();

			return false;
		}
		
		public static float GetVideoVC()
		{
			Debug.Log("[UNITY] Getting video vc ...");
			IPerformer performer = GetPerformer();
			if (performer != null)
				return performer.GetVideoVC();

			return -1;
		}
		
		public static string GetPokktSDKVersion()
		{
			Debug.Log("[UNITY] Getting Pokkt SDK version ...");
			IPerformer performer = GetPerformer();
			if (performer != null)
				return performer.GetPokktSDKVersion();

			return "";
		}
	}
}