//
//  AdColonyNetwork.m
//  SampleApp
//
//  Created by Pokkt on 10/16/15.
//  Copyright © 2015 Pokkt. All rights reserved.
//

#import "AdColonyNetwork.h"
#import "PokktNetworkDelegate.h"
#import "NetworkModel.h"
#import "PokktManager.h"

@implementation AdColonyNetwork

@synthesize networkName;

static bool isInitialized;
static bool isComplete;
static NSString *zoneId;
static NSString *AppId;
static NSArray *allZoneIds;

- (instancetype)init
{
    self = [super init];
    if (self)
    {
        
    }
    return self;
}

- (void)initNetwork:(PokktConfig *)pokktConfig networkModel:(NetworkModel *)customData
presentingViewController:(UIViewController *)viewController
{
    if (isInitialized) {
        return;
    }
    self.pokktConfig = pokktConfig;
    AppId = [customData.customData objectForKey:@"appId"];
    zoneId = [customData.customData objectForKey:@"zoneId"];
    allZoneIds = [customData.customData objectForKey:@"zoneId"];
    self.network = customData;
    dispatch_async(dispatch_get_main_queue(), ^{
        // do work here
        [AdColony configureWithAppID:AppId zoneIDs:@[zoneId] delegate:self logging:YES];
        isInitialized = YES;
    });
}

- (void)cacheVideo
{
    NSString *str = nil;
    
    NSUInteger status = [AdColony zoneStatusForZone:zoneId];
    if(status==ADCOLONY_ZONE_STATUS_ACTIVE){
        int reward = [AdColony getVirtualCurrencyRewardAmountForZone:zoneId];
        [PokktNetworkDelegate didFinishedVideoDownload:self.pokktConfig networkModel:self.network rewardValue:reward downLoadTime:@""];
        str = @"[AdColony SDK] AdColony video is available to watch";
    }else{
        if (![AdColony isVirtualCurrencyRewardAvailableForZone:zoneId]) {
            NSLog(@"[AdColony SDK] Ads not available for zone from adColony");
        }else{
            NSLog(@"[AdColony SDK] Ads Not Available right now !!");
        }
        [PokktNetworkDelegate didFailedVideoDownload:self.pokktConfig networkModel:self.network errorMessage:@"AdColony Rewarded video failed to load"];
    }
    NSLog(@"%@",str);
}

- (void)playVideo
{
    isComplete = NO;
    [AdColony playVideoAdForZone:zoneId withDelegate:self withV4VCPrePopup:NO andV4VCPostPopup:NO];
    NSLog(@"[AdColony SDK]AdColony Video Play");
}



#pragma mark - AdColony V4VC

//Callback activated when a V4VC currency reward succeeds or fails
//This implementation is designed for client-side virtual currency without a server
//It uses NSUserDefaults for persistent client-side storage of the currency balance
//For applications with a server, contact the server to retrieve an updated currency balance
//On success, posts an NSNotification so the rest of the app can update the UI
//On failure, posts an NSNotification so the rest of the app can disable V4VC UI elements
- (void)onAdColonyV4VCReward:(BOOL)success currencyName:(NSString*)currencyName currencyAmount:(int)amount inZone:(NSString*)zoneID {
    NSLog(@"AdColony SDK zone %@ reward %@ %i %@", zoneID, success ? @"YES" : @"NO", amount, currencyName);
    
    if (success) {
        //Post a notification so the rest of the app knows the balance changed
        [[NSNotificationCenter defaultCenter] postNotificationName:@"CurrencyBalanceChange" object:nil];
        if (!isComplete) {
            [PokktNetworkDelegate onVideoGratified:self.pokktConfig networkModel:self.network rewardPoint:amount];
            isComplete = YES;
            NSLog(@"[AdColony SDK] AdColony Video completed and gratified");
        }
        
    }
}

#pragma mark - AdColony ad fill

//Callback triggered when the state of ad readiness changes
//When the AdColony SDK tells us our zone either has, or doesn't have, ads, we
// need to tell our view controller to update its UI elements appropriately

- (void)onAdColonyAdAvailabilityChange:(BOOL)available inZone:(NSString*) zoneID {
    if (available) {
        NSLog(@"[AdColony SDK] Video became available in background !!");
    }else{
        NSLog(@"[AdColony SDK] Video is not available in background !!");
    }
}

- (void)onAdColonyAdStartedInZone:(NSString *)zoneID
{
    [PokktNetworkDelegate onVideoDisplayed:self.pokktConfig networkModel:self.network];
    NSLog(@"[AdColony SDK] AdColony Video Displayed");
}

- (void)onAdColonyAdAttemptFinished:(BOOL)shown inZone:(NSString *)zoneID
{
    if (shown) {
        [PokktNetworkDelegate onVideoCompleted:self.pokktConfig networkModel:self.network];
        NSLog(@"[AdColony SDK] AdColony Video download Closed");
    }
    else
    {
        [PokktNetworkDelegate onVideoSkipped:self.pokktConfig networkModel:self.network];
        NSLog(@"[AdColony SDK] AdColony Video download Skipped");
    }
    
    [PokktNetworkDelegate onVideoClosed:self.pokktConfig networkModel:self.network];
    
}

@end
