//
//  FyberNetwork.m
//  SampleApp
//
//  Created by Pokkt on 13/11/15.
//  Copyright © 2015 Pokkt. All rights reserved.
//

#import "FyberNetwork.h"
#import "PokktNetworkDelegate.h"
#import "NetworkModel.h"
#import "PokktManager.h"

@implementation FyberNetwork

@synthesize networkName;

static bool isInitialized;
static NSString *appId;
static NSString *token;

- (void)initNetwork:(PokktConfig *)pokktConfig networkModel:(NetworkModel *)customData
presentingViewController:(UIViewController *)viewController
{
    if (isInitialized)
    {
        return;
    }
    //playerVC = [[[UIApplication sharedApplication] keyWindow] rootViewController];
    
    self.playerVC = viewController;
    NSLog(@"1. Player view controller is null %@ %@",self.playerVC, viewController);
    if(self.playerVC == NULL)
        NSLog(@"2. Player view controller is null");
    self.network = customData;
    
    self.pokktConfig = pokktConfig;
    appId = [customData.customData objectForKey:@"AppKey"];
    token = [customData.customData objectForKey:@"security_token"];
    
    [FyberSDK setLoggingLevel:FYBLogLevelDebug];
    
    FYBSDKOptions *options = [FYBSDKOptions optionsWithAppId:appId securityToken:token];
    
    options.startVideoPrecaching = NO;
    
    [FyberSDK startWithOptions:options];
    
    isInitialized = YES;
    
    
    self.isVideoCached = NO;
    self.isTimedout = NO;
    
    NSLog(@"[Fyber SDK]Fyber Initialised");
    
    
}

- (void)cacheVideo
{
    NSString *str = nil;
    
    if (self.isVideoCached)
    {
        self.isVideoCached = NO;
        [PokktNetworkDelegate didFinishedVideoDownload: self.pokktConfig networkModel:self.network rewardValue:0 downLoadTime:@""];
        str = @"[Fyber SDK] Fyber video were already saved in cached";
    }
    else
    {
        
        FYBRewardedVideoController *rewardedVideoController = [FyberSDK rewardedVideoController];
        
        rewardedVideoController.delegate = self;
        
        rewardedVideoController.virtualCurrencyClientDelegate = self;
        FYBRequestParameters *parameters = [[FYBRequestParameters alloc] init];
        [rewardedVideoController requestVideoWithParameters:parameters];
        
        self.isTimedout = NO;
        int cacheTimeoutInterval = [PokktManager getCachingTimeoutDuration:self.network];
        self.cacheTimer = [NSTimer scheduledTimerWithTimeInterval:cacheTimeoutInterval target:self selector:@selector(updateTimer) userInfo:nil repeats:NO];
        
        str = @"[Fyber SDK] Fyber video caching start with timeout timer";
    }
    
    NSLog(@"%@",str);
    
}

- (void)playVideo
{
    NSLog(@"3. Player view controller is null%@", self.playerVC);
    [[FyberSDK rewardedVideoController] presentRewardedVideoFromViewController:self.playerVC];
}

- (void)updateTimer
{
    if (self.cacheTimer)
    {
        [self.cacheTimer invalidate];
        self.cacheTimer = nil;
        self.isTimedout = YES;
        
        [PokktNetworkDelegate didFailedVideoDownload:self.pokktConfig networkModel:self.network errorMessage:@"timed out"];
        NSLog(@"[Fyber SDK] Fyber Video caching request timeout due to low network.");
    }
}


- (void)rewardedVideoControllerDidReceiveVideo:(FYBRewardedVideoController *)rewardedVideoController
{
    NSString *str = nil;
    if (self.isTimedout)
    {
        self.isVideoCached = YES;
        str = @"[Fyber SDK] timeOut";
    }
    else
    {
        self.isVideoCached = NO;
        
        [self.cacheTimer invalidate];
        self.cacheTimer = nil;
        [PokktNetworkDelegate didFinishedVideoDownload: self.pokktConfig networkModel:self.network rewardValue:0 downLoadTime:@""];
        str = @"[Fyber SDK] Video downloaded";
    }
    
    NSLog(@"%@",str);
}

- (void)rewardedVideoController:(FYBRewardedVideoController *)rewardedVideoController didFailToReceiveVideoWithError:(NSError *)error
{
    self.isVideoCached = NO;
    
    if (self.isTimedout)
    {
        NSLog(@"%@",@"[Fyber SDK] failed to downlaod video after timeOut");
    }
    else
    {
        [self.cacheTimer invalidate];
        self.cacheTimer = nil;
        [PokktNetworkDelegate didFailedVideoDownload: self.pokktConfig networkModel:self.network errorMessage:error.description];
        NSLog(@"[Fyber SDK] error %@",error.description);
    }
    
}

#pragma mark FYBRewardedVideoControllerDelegate - Show Video

- (void)rewardedVideoControllerDidStartVideo:(FYBRewardedVideoController *)rewardedVideoController
{
    NSLog(@"[Fyber SDK]Video Started");
    [PokktNetworkDelegate onVideoDisplayed: self.pokktConfig networkModel:self.network];
}

- (void)rewardedVideoController:(FYBRewardedVideoController *)rewardedVideoController didDismissVideoWithReason:(FYBRewardedVideoControllerDismissReason)reason
{
    if (reason == FYBRewardedVideoControllerDismissReasonAborted )
    {
        [PokktNetworkDelegate onVideoSkipped:self.pokktConfig networkModel:self.network];
        [PokktNetworkDelegate onVideoClosed:self.pokktConfig networkModel:self.network];
        NSLog(@"View Controller Skipped Called");
        
        
    }
    else if (reason == FYBRewardedVideoControllerDismissReasonUserEngaged)
    {
        [PokktNetworkDelegate onVideoCompleted: self.pokktConfig networkModel:self.network];
        [PokktNetworkDelegate onVideoClosed:self.pokktConfig networkModel:self.network];
        NSLog(@"View Controller removed Completely");
    }
}

#pragma mark - FYBVirtualCurrencyClientDelegate

- (void)virtualCurrencyClient:(FYBVirtualCurrencyClient *)client didReceiveResponse:(FYBVirtualCurrencyResponse *)response
{
    NSLog(@"[Fyber SDK]Received %@ %@", @(response.deltaOfCoins), response.currencyName);
    
    [PokktNetworkDelegate onVideoGratified: self.pokktConfig networkModel:self.network rewardPoint:response.deltaOfCoins];
    
}

- (void)virtualCurrencyClient:(FYBVirtualCurrencyClient *)client didFailWithError:(NSError *)error
{
    NSLog(@"[Fyber SDK] Failed to receive virtual currency %@", error.description);
}

@end
