//
//  InmobiNetwork.m
//  SampleApp
//
//  Created by Subhendu Sekhar Sahu on 20/10/15.
//  Copyright © 2015 Pokkt. All rights reserved.
//

#import "InmobiNetwork.h"
#import "PokktNetworkDelegate.h"
#import <UIKit/UIKit.h>
#import "PokktManager.h"

@implementation InmobiNetwork

static NSString *networkType = @"InMobi";

- (void)initNetwork:(PokktConfig *)pokktConfig networkModel:(NetworkModel *)networkModel presentingViewController:(UIViewController *)viewController
{
    NSLog(@"%@ is initialised", networkType);

    self.pokktConfig = pokktConfig;
    
    self.networkModel = networkModel;
    
    self.viewController = viewController;

    NSString * accountID = [networkModel.customData objectForKey:@"AccountId"];

    [IMSdk initWithAccountID:accountID];
    
    NSString * placementID = [networkModel.customData objectForKey:@"PlacementId"];
    
    long long value = [placementID longLongValue];
    
    self.adInterstitial = [[IMInterstitial alloc] initWithPlacementId:value];
    self.adInterstitial.delegate = self;
    
    self.isVideoCached = NO;
    self.isTimedout = NO;
}

- (void)cacheVideo
{
    if (self.isVideoCached)
    {
        NSLog(@"%@ video cached previously", networkType);

            self.isVideoCached = NO;
            
            [PokktNetworkDelegate didFinishedVideoDownload:self.pokktConfig
                                          networkModel:self.networkModel
                                           rewardValue:0 downLoadTime:@""];
    }
    else
    {
        NSLog(@"%@ video caching started", networkType);

        self.isTimedout = NO;
        
        int cacheTimeoutInterval = [PokktManager getCachingTimeoutDuration:self.networkModel];
        
        [self.adInterstitial load];
        
        self.cacheTimer = [NSTimer scheduledTimerWithTimeInterval:cacheTimeoutInterval
                                                           target:self
                                                         selector:@selector(updateTimer)
                                                         userInfo:nil repeats:NO];
    }
}

- (void)playVideo
{
    if ([self.adInterstitial isReady])
    {
        NSLog(@"%@ play video called", networkType);

        [self.adInterstitial showFromViewController:self.viewController];
    }
}

- (void)updateTimer
{
    if (self.cacheTimer)
    {
        NSLog(@"%@ video caching timed out", networkType);

        [self.cacheTimer invalidate];
        self.cacheTimer = nil;
        self.isTimedout = YES;
        
        [PokktNetworkDelegate didFailedVideoDownload:self.pokktConfig networkModel:self.networkModel errorMessage:@"timed out"];
    }
}

/*Indicates that the interstitial has received an ad. */
- (void)interstitialDidFinishLoading:(IMInterstitial *)interstitial
{
    NSLog(@"interstitialDidFinishLoading");

    if (self.isTimedout)
    {
        NSLog(@"%@ video caching successful after timeout", networkType);

        self.isVideoCached = YES;
    }
    else
    {
        self.isVideoCached = NO;

        NSLog(@"%@ video caching successful before timeout", networkType);

        [self.cacheTimer invalidate];
        self.cacheTimer = nil;
        
        [PokktNetworkDelegate didFinishedVideoDownload:self.pokktConfig
                                          networkModel:self.networkModel
                                           rewardValue:0 downLoadTime:@""];
    }

}

/* Indicates that the interstitial has failed to receive an ad */
- (void)interstitial:(IMInterstitial *)interstitial didFailToLoadWithError:(IMRequestStatus *)error
{
    self.isVideoCached = NO;

    if (self.isTimedout)
    {
        NSLog(@"%@ video caching failed after timeout", networkType);
    }
    else
    {
        NSLog(@"%@ video caching failed before timeout", networkType);
        
        [self.cacheTimer invalidate];
        self.cacheTimer = nil;
        
        [PokktNetworkDelegate didFailedVideoDownload:self.pokktConfig networkModel:self.networkModel errorMessage:error.description];
    }
}

/* Indicates that the interstitial has failed to present itself. */
- (void)interstitial:(IMInterstitial *)interstitial didFailToPresentWithError:(IMRequestStatus *)error
{
    NSLog(@"Interstitial didFailToPresentWithError");
    NSLog(@"Error : %@",error.description);

    NSLog(@"%@ video download failed", networkType);
    
    self.isVideoCached = NO;
    
    [PokktNetworkDelegate onVideoClosed:self.pokktConfig networkModel:self.networkModel];
}

/* indicates that the interstitial is going to present itself. */
- (void)interstitialWillPresent:(IMInterstitial *)interstitial
{
    NSLog(@"interstitialWillPresent");
}
/* Indicates that the interstitial has presented itself */
- (void)interstitialDidPresent:(IMInterstitial *)interstitial
{
    NSLog(@"interstitialDidPresent");
    [PokktNetworkDelegate onVideoDisplayed:self.pokktConfig networkModel:self.networkModel];
}

/* Indicates that the interstitial is going to dismiss itself. */
- (void)interstitialWillDismiss:(IMInterstitial *)interstitial
{
    NSLog(@"interstitialWillDismiss");
    [PokktNetworkDelegate onVideoClosed:self.pokktConfig networkModel:self.networkModel];
}

/* Indicates that the interstitial has dismissed itself. */
- (void)interstitialDidDismiss:(IMInterstitial *)interstitial
{
    NSLog(@"interstitialDidDismiss");
}

/* Indicates that the user will leave the app. */
- (void)userWillLeaveApplicationFromInterstitial:(IMInterstitial *)interstitial
{
    NSLog(@"userWillLeaveApplicationFromInterstitial");
}

/* Indicates that a reward action is completed */
- (void)interstitial:(IMInterstitial *)interstitial rewardActionCompletedWithRewards:(NSDictionary *)rewards
{
    // Extract the reward points as  key entered in the inmobi dashbpard
    
    NSLog(@"%@ video completed", networkType);
    
    [PokktNetworkDelegate onVideoCompleted:self.pokktConfig networkModel:self.networkModel];

    NSLog(@"IncentActionCompleted Publisher Callback successfully received");
    
    [PokktNetworkDelegate onVideoGratified:self.pokktConfig networkModel:self.networkModel rewardPoint:[[rewards objectForKey:@"reward"] floatValue]];
}

/* interstitial:didInteractWithParams: Indicates that the interstitial was interacted with. */
- (void)interstitial:(IMInterstitial *)interstitial didInteractWithParams:(NSDictionary *)params
{
    NSLog(@"InterstitialDidInteractWithParams");
}
@end
