//
//  UnityAdsNetwork.m
//  SampleApp
//
//  Created by Pokkt on 01/12/15.
//  Copyright © 2015 Pokkt. All rights reserved.
//

#import "UnityAdsNetwork.h"
#import "PokktNetworkDelegate.h"
#import "NetworkModel.h"
#import "PokktManager.h"
#import <UnityAds/UnityAds.h>

@implementation UnityAdsNetwork

@synthesize networkName;

static bool isInitialized;
static NSString *gameId;
static NSString *gamersID;
static NSString *rewardAmount;

- (void)initNetwork:(PokktConfig *)pokktConfig networkModel:(NetworkModel *)customData
presentingViewController:(UIViewController *)viewController
{
    if (isInitialized)
    {
        return;
    }
    self.playerVC = viewController;
    self.network = customData;
    //Test gameID = 91705 and zone is "testVideo"
    
    self.pokktConfig = pokktConfig;
    
    gameId = [customData.customData objectForKey:@"gameId"];
    rewardAmount = [customData.customData objectForKey:@"rewardAmount"];
    
    gamersID = self.pokktConfig.thirdPartyUserId;
    
    [[UnityAds sharedInstance] startWithGameId:gameId andViewController:self.playerVC];
    [[UnityAds sharedInstance] setDelegate:self];
    
    isInitialized = YES;
    
    NSLog(@"[UnityAds SDK]UnityAds Initialised");
}

- (void)cacheVideo
{
    NSString *str = nil;
    [[UnityAds sharedInstance] setZone:@"rewardedVideoZone"];
    
    if ([[UnityAds sharedInstance] canShow])
    {
        [PokktNetworkDelegate didFinishedVideoDownload:self.pokktConfig networkModel:self.network rewardValue:0 downLoadTime:@""];
        str = @"[UnityAds SDK] UnityAds video is available to watch";
    }
    else
    {
        [PokktNetworkDelegate didFailedVideoDownload:self.pokktConfig networkModel:self.network errorMessage:@"Ad Not Available!!"];
        str = @"[UnityAds SDK] UnityAds video is not available right now!!";
    }
    
    NSLog(@"%@",str);
}

- (void)playVideo
{
    [[UnityAds sharedInstance] show:@{
                                      kUnityAdsOptionNoOfferscreenKey:@true,
                                      kUnityAdsOptionOpenAnimatedKey:@true,
                                      kUnityAdsOptionGamerSIDKey:gamersID,
                                      kUnityAdsOptionMuteVideoSounds:@false,
                                      kUnityAdsOptionVideoUsesDeviceOrientation:@true
                                      }];
    
    NSLog(@"[UnityAds SDK]UnityAds Video Play");
}

- (void)unityAdsVideoCompleted:(NSString *)rewardItemKey skipped:(BOOL)skipped
{
    NSLog(@"unityAdsVideoCompleted:rewardItemKey:skipped: -- key: %@", rewardItemKey);
    if (skipped) {
        [PokktNetworkDelegate onVideoSkipped:self.pokktConfig networkModel:self.network];
    }
    else
    {
        [PokktNetworkDelegate onVideoCompleted:self.pokktConfig networkModel:self.network];
        [PokktNetworkDelegate onVideoGratified:self.pokktConfig networkModel:self.network rewardPoint:[rewardAmount floatValue]];
    }
}

- (void)unityAdsWillShow
{
    NSLog(@"Unity AdsWillShow");
}

- (void)unityAdsDidShow
{
    NSLog(@"Unity AdsDidShow");
}

- (void)unityAdsWillHide;
{
    NSLog(@"Unity video closed");
    [PokktNetworkDelegate onVideoClosed:self.pokktConfig networkModel:self.network];
}


- (void)unityAdsVideoStarted
{
    NSLog(@"Unity Video Started");
    [PokktNetworkDelegate onVideoDisplayed:self.pokktConfig networkModel:self.network];
}

- (void)unityAdsFetchCompleted
{
    NSLog(@"Unity fetch completed");
}

- (void)unityAdsFetchFailed
{
    NSLog(@"Unity video failed with error");
}
@end
