//
//  VungalNetwork.m
//  SampleApp
//
//  Created by Subhendu Sekhar Sahu on 01/12/15.
//  Copyright © 2015 Pokkt. All rights reserved.
//

#import "VungleNetwork.h"
#import "PokktNetworkDelegate.h"

@implementation VungleNetwork

static NSString *networkType = @"Vungle";

- (instancetype)init
{
    self = [super init];
    if (self)
    {
        
    }
    return self;
}

- (void) initNetwork:(PokktConfig *)pokktConfig networkModel:(NetworkModel *)networkModel presentingViewController:(UIViewController *)viewController
{
    NSLog(@"%@ is initialised", networkType);
    
    self.pokktConfig = pokktConfig;
    
    self.networkModel  =networkModel;
    
    self.viewController = viewController;
    
    NSString * appId = [networkModel.customData objectForKey:@"appId"];

    VungleSDK *sdk = [VungleSDK sharedSDK];
    
    [sdk startWithAppId:appId];
    
    [[VungleSDK sharedSDK] setDelegate:self];
}

- (void)cacheVideo
{
    NSLog(@"%@ video caching started", networkType);

    if( [[VungleSDK sharedSDK] isAdPlayable])
    {
        [PokktNetworkDelegate didFinishedVideoDownload:self.pokktConfig
                                          networkModel:self.networkModel
                                           rewardValue:0 downLoadTime:@""];
    }
    else
    {
        [PokktNetworkDelegate didFailedVideoDownload:self.pokktConfig networkModel:self.networkModel errorMessage:@"Video is not available"];
 
    }
}

- (void)playVideo
{
    NSLog(@"%@ play video called", networkType);

    // Grab instance of Vungle SDK
    VungleSDK* sdk = [VungleSDK sharedSDK];
    
    // Dict to set custom ad options
    NSDictionary* options = @{VunglePlayAdOptionKeyIncentivized: @YES,
                              VunglePlayAdOptionKeyIncentivizedAlertBodyText : @"If the video isn't completed you won't get your reward! Are you sure you want to close early?",
                              VunglePlayAdOptionKeyIncentivizedAlertCloseButtonText : @"Close",
                              VunglePlayAdOptionKeyIncentivizedAlertContinueButtonText : @"Keep Watching",
                              VunglePlayAdOptionKeyIncentivizedAlertTitleText : @"Careful!",
                              VunglePlayAdOptionKeyUser:self.pokktConfig.thirdPartyUserId};
    
    // Pass in dict of options, play ad
    NSError *error;
    
    [sdk playAd:self.viewController withOptions:options error:&error];
    
    if (error)
    {
        NSLog(@"Error encountered playing ad: %@", error);
    }
    

}

#pragma mark -
#pragma mark - VungleSDK Delegate
#pragma mark - 

- (void)vungleSDKAdPlayableChanged:(BOOL)isAdPlayable
{
    if (isAdPlayable)
    {
        NSLog(@"%@ ad is available for playback", networkType);
    }
    else
    {
        NSLog(@"%@ ads currently available for playback", networkType);
    }
}

- (void)vungleSDKwillShowAd
{
    NSLog(@"%@ ad is about to be played!", networkType);
    //Use this delegate method to pause animations, sound, etc.
    
    [PokktNetworkDelegate onVideoDisplayed:self.pokktConfig networkModel:self.networkModel];
}

- (void) vungleSDKwillCloseAdWithViewInfo:(NSDictionary *)viewInfo willPresentProductSheet:(BOOL)willPresentProductSheet
{
    if (willPresentProductSheet)
    {
        //In this case we don't want to resume animations and sound, the user hasn't returned to the app yet
        NSLog(@"The ad presented was tapped and the user is now being shown the App Product Sheet");
        
        NSLog(@"ViewInfo Dictionary:");
        
        for(NSString * key in [viewInfo allKeys])
        {
            NSLog(@"%@ : %@", key, [[viewInfo objectForKey:key] description]);
        }
    }
    else
    {
        //In this case the user has declined to download the advertised application and is now returning fully to the main app
        //Animations / Sound / Gameplay can be resumed now
        NSLog(@"The ad presented was not tapped - the user has returned to the app");
        NSLog(@"ViewInfo Dictionary:");
        
        for(NSString * key in [viewInfo allKeys])
        {
            NSLog(@"%@ : %@", key, [[viewInfo objectForKey:key] description]);
        }
    }
    
    if ([[viewInfo objectForKey:@"completedView"] intValue] == 1)
    {
        [PokktNetworkDelegate onVideoCompleted:self.pokktConfig networkModel:self.networkModel];
    }
    else
    {
        [PokktNetworkDelegate onVideoSkipped:self.pokktConfig networkModel:self.networkModel];
    }
   
    [PokktNetworkDelegate onVideoClosed:self.pokktConfig networkModel:self.networkModel];
}

- (void)vungleSDKwillCloseProductSheet:(id)productSheet
{
    NSLog(@"The user has downloaded an advertised application and is now returning to the main app");
    //This method can be used to resume animations, sound, etc. if a user was presented a product sheet earlier
}

@end
